@@ -1,6 +1,6 @@
 package UI::Dialog::Backend;
 ###############################################################################
-#  Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
+#  Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,6 @@ package UI::Dialog::Backend;
 ###############################################################################
 use 5.006;
 use strict;
-use warnings;
-use diagnostics;
 use Carp;
 use Cwd qw( abs_path );
 use File::Basename;
@@ -27,7 +25,7 @@ use Text::Wrap qw( wrap );
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION = '1.00';
+    $VERSION = '1.09';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -67,7 +65,7 @@ sub nautilus {
 #: Provide the API interface to osd_cat (aka: xosd)
 sub xosd {
     my $self = shift();
-    my @args = (@_) ? @_ : ();
+    my @args = (@_ %2 == 0) ? (@_) : ();
     my $xosd = $self->{'_xosd'} || {};
     unless (ref($xosd) eq "UI::Dialog::Backend::XOSD") {
 		if ($self->_find_bin('osd_cat')) {
@@ -106,6 +104,7 @@ sub ra {
     $self->_debug((join(" | ",(caller())))." > ra() > rset: ".((@_) ? "@_" : 'NULL'),3);
     $self->{'_state'}->{'ra'} = ($_[0] =~ /^null$/i) ? [ 0 ] : [ @_ ] unless not @_;
     my $aref = $self->{'_state'}->{'ra'};
+	ref($aref) eq "ARRAY" or $aref = [];
     return(@{$aref});
 }
 
@@ -221,11 +220,18 @@ sub gen_tempfile_name {
     my $self = $_[0];
     my $template = $self->{'_opts'}->{'tempfiletemplate'} || "UI_Dialog_tempfile_XXXXX";
     if (eval("require File::Temp; 1")) {
-		use File::Temp qw( mktemp );
-		return(File::Temp::mktemp($template));
+		use File::Temp qw( tempfile );
+		my ($fh,$filename) = tempfile( UNLINK => 1 ) or croak( "Can't create tempfile: $!" );
+        if (wantarray) {
+            return($fh,$filename);
+        } else {
+            close($fh); # actually required on win32
+            return($filename);
+        }
+        return($fh,$filename);
     } else {
 		my $mktemp = $self->_find_bin('mktemp');
-		if (-x $mktemp) {
+		if ($mktemp && -x $mktemp) {
 			chomp(my $tempfile = `$mktemp "$template"`);
 			return($tempfile);
 		} else {
@@ -238,8 +244,10 @@ sub gen_tempfile_name {
 					$tempdir = ".";
 				}
 			}
+			$self->gen_random_string(5);
 			my $tempfile = "UI_Dialog_tempfile_".$self->gen_random_string(5);
 			while (-e $tempdir."/".$tempfile) {
+				$self->gen_random_string(5);
 				$tempfile = "UI_Dialog_tempfile_".$self->gen_random_string(5);
 			}
 			return($tempdir."/".$tempfile);
