@@ -1,6 +1,6 @@
 package UI::Dialog::Backend::XOSD;
 ###############################################################################
-#  Copyright (C) 2003  Kevin C. Krinke <kckrinke@opendoorsoftware.com>
+#  Copyright (C) 2013  Kevin C. Krinke <kevin@krinke.ca>
 #
 #  This library is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,6 @@ package UI::Dialog::Backend::XOSD;
 ###############################################################################
 use 5.006;
 use strict;
-use warnings;
-use diagnostics;
 use Carp;
 use UI::Dialog::Backend;
 use FileHandle;
@@ -37,7 +35,7 @@ use FileHandle;
 BEGIN {
     use vars qw( $VERSION @ISA );
     @ISA = qw( UI::Dialog::Backend );
-    $VERSION = '1.00';
+    $VERSION = '1.09';
 }
 
 sub new {
@@ -47,6 +45,16 @@ sub new {
     my $self = {};
     bless($self, $class);
     $self->{'_opts'} = {};
+
+	#: Dynamic path discovery...
+	my $CFG_PATH = $cfg->{'PATH'};
+	if ($CFG_PATH) {
+		if (ref($CFG_PATH) eq "ARRAY") { $self->{'PATHS'} = $CFG_PATH; }
+		elsif ($CFG_PATH =~ m!:!) { $self->{'PATHS'} = [ split(/:/,$CFG_PATH) ]; }
+		elsif (-d $CFG_PATH) { $self->{'PATHS'} = [ $CFG_PATH ]; }
+	} elsif ($ENV{'PATH'}) { $self->{'PATHS'} = [ split(/:/,$ENV{'PATH'}) ]; }
+	else { $self->{'PATHS'} = ''; }
+
     $self->{'_opts'}->{'bin'} = $self->_find_bin('osd_cat');
     $self->{'_opts'}->{'tail'} = $self->_find_bin('tail');
     $self->{'_opts'}->{'kill'} = $self->_find_bin('kill');
@@ -155,11 +163,9 @@ sub file {
     my $opts = $self->_gen_opt_str($args);
     if (-r $args->{'file'}) {
 		if (open(FILE,"<".$args->{'file'})) {
-			my $TS = $/;
-			undef($/);
+			local $/;
 			my $text = <FILE>;
 			close(FILE);
-			$/ = $TS;
 			$text =~ s!\t!    !g;
 			if (open(XOSD,"| ".$self->{'_opts'}->{'bin'}.$opts." -")) {
 				print XOSD ($text||'')."\n";
